<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://www.simonebaldini.dev
 * @since      1.0.0
 *
 * @package    Enhanced_Search
 * @subpackage Enhanced_Search/admin/partials
 */

add_thickbox();
$post_types = get_post_types( [ 'public' => true ], 'objects' );
$attributes = [
	'post_title'   => __( 'Post title', 'search' ),
	'post_excerpt' => __( 'Post excerpt', 'search' ),
	'post_content' => __( 'Post content', 'search' ),
];
$taxonomies = get_taxonomies( [ 'public' => true ], 'objects' );
?>

<div id="reindex-modal-window" style="display:none;">
	<div class="reindex-modal-window">
		<h2><?php _e( 'Reindex is running...', 'enhanced-search' ); ?></h2>
		<span>
		<?php
			_e(
				'This operation could take a long time. Please wait until it is completed.',
				'enhanced-search'
			);
			?>
		<br/>
		<?php
			_e(
				'Once it will be completed you will able to change the search settings <strong>without having to re-run it</strong>.',
				'enhanced-search'
			);
			?>
		</span>
		<img src="<?php echo plugin_dir_url( __DIR__ ); ?>/images/reindex.gif" />
		<div class="progress-bar">
			<div class="progress"></div>
		</div>
	</div>
</div>

<div class="wrap">
	<h1>Enhanced Search</h1>
	<form method="post">
		<div class="enhanced-search-settings-row">
			<div class="enhanced-search-settings">
				<h2><?php _e( 'Post types', 'enhanced-search' ); ?></h2>
				<?php foreach ( $post_types as $post_type ) { ?>
					<table class="form-table" role="presentation">
						<tr>
							<th scope="row">
								<?php _e( $post_type->label, 'enhanced-search' ); ?>
							</th>
							<td>
								<label class="switch">
									<input name="enhanced_search[post_types][<?php echo $post_type->name; ?>][active]" value="on" type="checkbox" <?php echo $this->get_option( "post_types/{$post_type->name}/active" ) ? 'checked' : ''; ?>>
									<span class="slider round"></span>
								</label>
							</td>
						<tr class="rangeslider-row">
							<th scope="row">
								— <?php _e( 'Boost', 'enhanced-search' ); ?>
							</th>
							<td>
								<input name="enhanced_search[post_types][<?php echo $post_type->name; ?>][boost]" type="range" min="0" max="1" step="0.05" value="<?php echo $this->get_option( "post_types/{$post_type->name}/boost", 1 ); ?>">
							</td>
						</tr>
					</table>
				<?php } ?>
			</div>

			<div class="enhanced-search-settings">
				<h2><?php _e( 'Post attributes', 'enhanced-search' ); ?></h2>
				<?php foreach ( $attributes as $name => $label ) { ?>
					<table class="form-table" role="presentation">
						<tr>
							<th scope="row">
								<?php echo $label; ?>
							</th>
							<td>
								<label class="switch">
									<input name="enhanced_search[attributes][<?php echo $name; ?>][active]" value="on" type="checkbox" <?php echo $this->get_option( "attributes/{$name}/active" ) ? 'checked' : ''; ?>>
									<span class="slider round"></span>
								</label>
							</td>
						</tr>
						<tr class="rangeslider-row">
							<th scope="row">
								— <?php _e( 'Sensibility', 'enhanced-search' ); ?>
							</th>
							<td>
								<input name="enhanced_search[attributes][<?php echo $name; ?>][sensibility]" type="range" min="0" max="1" step="0.05" value="<?php echo $this->get_option( "attributes/{$name}/sensibility", 0.8 ); ?>">
							</td>
						</tr>
						<tr class="rangeslider-row">
							<th scope="row">
								— <?php _e( 'Boost', 'enhanced-search' ); ?>
							</th>
							<td>
								<input name="enhanced_search[attributes][<?php echo $name; ?>][boost]" type="range" min="1" max="10" step="0.5" value="<?php echo $this->get_option( "attributes/{$name}/boost", 1 ); ?>">
							</td>
						</tr>
					</table>
				<?php } ?>
			</div>

			<div class="enhanced-search-settings">
				<h2><?php _e( 'Taxonomies', 'enhanced-search' ); ?></h2>
				<?php foreach ( $taxonomies as $taxonomy ) { ?>
					<table class="form-table" role="presentation">
						<tr>
							<th scope="row">
								<?php _e( $taxonomy->label, 'search' ); ?>
							</th>
							<td>
								<label class="switch">
									<input name="enhanced_search[taxonomies][<?php echo $taxonomy->name; ?>][active]" value="on" type="checkbox" <?php echo $this->get_option( "taxonomies/{$taxonomy->name}/active" ) ? 'checked' : ''; ?>>
									<span class="slider round"></span>
								</label>
							</td>
						</tr>
						<tr class="rangeslider-row">
							<th scope="row">
								— <?php _e( 'Sensibility', 'enhanced-search' ); ?>
							</th>
							<td>
								<input name="enhanced_search[taxonomies][<?php echo $taxonomy->name; ?>][sensibility]" type="range" min="0" max="1" step="0.05" value="<?php echo $this->get_option( "taxonomies/{$taxonomy->name}/sensibility", 0.8 ); ?>">
							</td>
						</tr>
						<tr class="rangeslider-row">
							<th scope="row">
								— <?php _e( 'Boost', 'enhanced-search' ); ?>
							</th>
							<td>
								<input name="enhanced_search[taxonomies][<?php echo $taxonomy->name; ?>][boost]" type="range" min="1" max="10" step="0.5" value="<?php echo $this->get_option( "taxonomies/{$taxonomy->name}/boost", 1 ); ?>">
							</td>
						</tr>
					</table>
				<?php } ?>
			</div>
		</div>

		<hr />
		<div class="buttons">
			<button class="btn button" type="button"><?php _e( 'Reindex', 'enhanced-search' ); ?></button>
			<button type="submit" name="submit" id="submit" class="button button-primary"><?php _e( 'Save Changes', 'enhanced-search' ); ?></button>
			<?php wp_nonce_field( '_enhanced_search_nonce' ); ?>
		</div>
	</form>
</div>
