<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.simonebaldini.dev
 * @since             1.2.0
 * @package           Enhanced_Search
 *
 * @wordpress-plugin
 * Plugin Name:       Enhanced Search
 * Description:       WordPress plugin that improves basic search givin you the possibility to do a fine tuning.
 * Version:           1.2.0
 * Author:            Simone Baldini
 * Author URI:        https://www.simonebaldini.dev
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       enhanced-search
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'ENHANCED_SEARCH_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-enhanced-search-activator.php
 */
function activate_enhanced_search() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-enhanced-search-activator.php';
	Enhanced_Search_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-enhanced-search-deactivator.php
 */
function deactivate_enhanced_search() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-enhanced-search-deactivator.php';
	Enhanced_Search_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_enhanced_search' );
register_deactivation_hook( __FILE__, 'deactivate_enhanced_search' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-enhanced-search-settings.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-enhanced-search.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_enhanced_search() {

	$plugin = new Enhanced_Search();
	$plugin->run();

}
run_enhanced_search();
