<?php

/**
 *
 * @since      1.0.0
 * @package    Enhanced_Search
 * @subpackage Enhanced_Search/includes
 * @author     Simone Baldini <info@simonebaldini.dev>
 */
abstract class Enhanced_Search_Settings {

	const SETTINGS_KEY     = 'enhanced_search';
	const DEFAULT_SETTINGS = [
		'post_types' => [
			'post' => [
				'active' => true,
				'boost'  => 1,
			],
			'page' => [
				'active' => true,
				'boost'  => 0.75,
			],
		],
		'attributes' => [
			'post_title'   => [
				'active'      => true,
				'sensibility' => 0.65,
				'boost'       => 8,
			],
			'post_excerpt' => [
				'active'      => true,
				'sensibility' => 0.85,
				'boost'       => 6,
			],
			'post_content' => [
				'active'      => true,
				'sensibility' => 0.85,
				'boost'       => 4,
			],
		],
		'taxonomies' => [
			'category' => [
				'active'      => true,
				'sensibility' => 0.75,
				'boost'       => 5,
			],
			'post_tag' => [
				'active'      => true,
				'sensibility' => 0.75,
				'boost'       => 5,
			],
		],
	];

	/**
	 * Get plugin settings value.
	 *
	 * @param string $path Setting path.
	 * @param mixed  $default Default value.
	 * @since  1.0.0
	 * @return mixed
	 */
	protected function get_option( $path, $default = null ) {
		$current = get_option( self::SETTINGS_KEY, self::DEFAULT_SETTINGS );
		$keys    = explode( '/', $path );
		while ( $current && $keys ) {
			$key     = array_shift( $keys );
			$current = is_array( $current ) && array_key_exists( $key, $current )
				? $current[ $key ]
				: $default;
		}

		return $current ?: $default;
	}

}
